==> hs-HDBC-2.3.1.0p0.tgz: lib/ghc/HDBC-2.3.1.0/register.sh <==
#!/bin/sh
echo 'name: HDBC
version: 2.3.1.0
id: HDBC-2.3.1.0-cc9add2fc70b0459c7a9445102c47d26

license: BSD3
copyright: Copyright (c) 2005-2011 John Goerzen
maintainer: Nicolas Wu <nick@well-typed.com>
stability: Stable
homepage: https://github.com/jgoerzen/hdbc/wiki
package-url:
description: HDBC provides an abstraction layer between Haskell programs and SQL
             relational databases. This lets you write database code once, in
             Haskell, and have it work with any number of backend SQL databases
             (MySQL, Oracle, PostgreSQL, ODBC-compliant databases, etc.)
category: Database
author: John Goerzen
pkgpath: databases/hs-HDBC
exposed: True
exposed-modules: Database.HDBC Database.HDBC.Types
                 Database.HDBC.DriverUtils Database.HDBC.ColTypes
                 Database.HDBC.Statement Database.HDBC.SqlValue Database.HDBC.Locale
hidden-modules: Database.HDBC.Utils
import-dirs: /usr/local/lib/ghc/HDBC-2.3.1.0
library-dirs: /usr/local/lib/ghc/HDBC-2.3.1.0
hs-libraries: HSHDBC-2.3.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
         convertible-1.0.11.0-da995ca9bb94cdaf09d424d894cde7fc
         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
         old-locale-1.0.0.2-161f79060c89cc16ca11576ceb440486
         old-time-1.0.0.6-088ba18f14be11f5303a5ce07fd2f643
         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
         time-1.2.0.3-3493203919ef238f1a58223fa55b1ceb
         utf8-string-0.3.6-213e09c7f4f705610e4e35b79f03acb5
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HDBC-2.3.1.0/html/HDBC.haddock
haddock-html: /usr/local/share/doc/hs-HDBC-2.3.1.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-HDBC-2.3.1.1.tgz: lib/ghc/HDBC-2.3.1.1/register.sh <==
#!/bin/sh
echo 'name: HDBC
version: 2.3.1.1
id: HDBC-2.3.1.1-70f73b84bbe34c5e07c75115b1914a87

license: BSD3
copyright: Copyright (c) 2005-2011 John Goerzen
maintainer: Nicolas Wu <nick@well-typed.com>
stability: Stable
homepage: https://github.com/hdbc/hdbc
package-url:
description: HDBC provides an abstraction layer between Haskell programs and SQL
             relational databases. This lets you write database code once, in
             Haskell, and have it work with any number of backend SQL databases
             (MySQL, Oracle, PostgreSQL, ODBC-compliant databases, etc.)
category: Database
author: John Goerzen
pkgpath: databases/hs-HDBC
exposed: True
exposed-modules: Database.HDBC Database.HDBC.Types
                 Database.HDBC.DriverUtils Database.HDBC.ColTypes
                 Database.HDBC.Statement Database.HDBC.SqlValue Database.HDBC.Locale
hidden-modules: Database.HDBC.Utils
import-dirs: /usr/local/lib/ghc/HDBC-2.3.1.1
library-dirs: /usr/local/lib/ghc/HDBC-2.3.1.1
hs-libraries: HSHDBC-2.3.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
         convertible-1.0.11.1-7977f1714e1906d369ab9f369968c666
         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
         old-locale-1.0.0.2-161f79060c89cc16ca11576ceb440486
         old-time-1.0.0.6-088ba18f14be11f5303a5ce07fd2f643
         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
         time-1.2.0.3-3493203919ef238f1a58223fa55b1ceb
         utf8-string-0.3.6-213e09c7f4f705610e4e35b79f03acb5
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HDBC-2.3.1.1/html/HDBC.haddock
haddock-html: /usr/local/share/doc/hs-HDBC-2.3.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
